# Copyright (c) 2017-2022 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/admin/metering_report_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='com/daml/ledger/api/v1/admin/metering_report_service.proto',
  package='com.daml.ledger.api.v1.admin',
  syntax='proto3',
  serialized_options=b'\n\034com.daml.ledger.api.v1.adminB\030MeteringReportOuterClassZUgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1/admin\252\002\034Com.Daml.Ledger.Api.V1.Admin',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:com/daml/ledger/api/v1/admin/metering_report_service.proto\x12\x1c\x63om.daml.ledger.api.v1.admin\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9d\x01\n\x18GetMeteringReportRequest\x12.\n\x04\x66rom\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x66rom\x12*\n\x02to\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02to\x12%\n\x0e\x61pplication_id\x18\x03 \x01(\tR\rapplicationId\"\xa7\x02\n\x19GetMeteringReportResponse\x12P\n\x07request\x18\x01 \x01(\x0b\x32\x36.com.daml.ledger.api.v1.admin.GetMeteringReportRequestR\x07request\x12\x66\n\x12participant_report\x18\x02 \x01(\x0b\x32\x37.com.daml.ledger.api.v1.admin.ParticipantMeteringReportR\x11participantReport\x12P\n\x16report_generation_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x14reportGenerationTime\"\xe5\x01\n\x19ParticipantMeteringReport\x12%\n\x0eparticipant_id\x18\x01 \x01(\tR\rparticipantId\x12\x37\n\tto_actual\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08toActual\x12h\n\x13\x61pplication_reports\x18\x03 \x03(\x0b\x32\x37.com.daml.ledger.api.v1.admin.ApplicationMeteringReportR\x12\x61pplicationReports\"c\n\x19\x41pplicationMeteringReport\x12%\n\x0e\x61pplication_id\x18\x01 \x01(\tR\rapplicationId\x12\x1f\n\x0b\x65vent_count\x18\x02 \x01(\x03R\neventCount2\x9e\x01\n\x15MeteringReportService\x12\x84\x01\n\x11GetMeteringReport\x12\x36.com.daml.ledger.api.v1.admin.GetMeteringReportRequest\x1a\x37.com.daml.ledger.api.v1.admin.GetMeteringReportResponseB\xae\x01\n\x1c\x63om.daml.ledger.api.v1.adminB\x18MeteringReportOuterClassZUgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1/admin\xaa\x02\x1c\x43om.Daml.Ledger.Api.V1.Adminb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_GETMETERINGREPORTREQUEST = _descriptor.Descriptor(
  name='GetMeteringReportRequest',
  full_name='com.daml.ledger.api.v1.admin.GetMeteringReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from', full_name='com.daml.ledger.api.v1.admin.GetMeteringReportRequest.from', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='from', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='com.daml.ledger.api.v1.admin.GetMeteringReportRequest.to', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='to', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_id', full_name='com.daml.ledger.api.v1.admin.GetMeteringReportRequest.application_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='applicationId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=283,
)


_GETMETERINGREPORTRESPONSE = _descriptor.Descriptor(
  name='GetMeteringReportResponse',
  full_name='com.daml.ledger.api.v1.admin.GetMeteringReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='com.daml.ledger.api.v1.admin.GetMeteringReportResponse.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='request', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_report', full_name='com.daml.ledger.api.v1.admin.GetMeteringReportResponse.participant_report', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='participantReport', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report_generation_time', full_name='com.daml.ledger.api.v1.admin.GetMeteringReportResponse.report_generation_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reportGenerationTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=581,
)


_PARTICIPANTMETERINGREPORT = _descriptor.Descriptor(
  name='ParticipantMeteringReport',
  full_name='com.daml.ledger.api.v1.admin.ParticipantMeteringReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_id', full_name='com.daml.ledger.api.v1.admin.ParticipantMeteringReport.participant_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='participantId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_actual', full_name='com.daml.ledger.api.v1.admin.ParticipantMeteringReport.to_actual', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='toActual', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='application_reports', full_name='com.daml.ledger.api.v1.admin.ParticipantMeteringReport.application_reports', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='applicationReports', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=584,
  serialized_end=813,
)


_APPLICATIONMETERINGREPORT = _descriptor.Descriptor(
  name='ApplicationMeteringReport',
  full_name='com.daml.ledger.api.v1.admin.ApplicationMeteringReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='application_id', full_name='com.daml.ledger.api.v1.admin.ApplicationMeteringReport.application_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='applicationId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_count', full_name='com.daml.ledger.api.v1.admin.ApplicationMeteringReport.event_count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='eventCount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=815,
  serialized_end=914,
)

_GETMETERINGREPORTREQUEST.fields_by_name['from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETMETERINGREPORTREQUEST.fields_by_name['to'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETMETERINGREPORTRESPONSE.fields_by_name['request'].message_type = _GETMETERINGREPORTREQUEST
_GETMETERINGREPORTRESPONSE.fields_by_name['participant_report'].message_type = _PARTICIPANTMETERINGREPORT
_GETMETERINGREPORTRESPONSE.fields_by_name['report_generation_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PARTICIPANTMETERINGREPORT.fields_by_name['to_actual'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PARTICIPANTMETERINGREPORT.fields_by_name['application_reports'].message_type = _APPLICATIONMETERINGREPORT
DESCRIPTOR.message_types_by_name['GetMeteringReportRequest'] = _GETMETERINGREPORTREQUEST
DESCRIPTOR.message_types_by_name['GetMeteringReportResponse'] = _GETMETERINGREPORTRESPONSE
DESCRIPTOR.message_types_by_name['ParticipantMeteringReport'] = _PARTICIPANTMETERINGREPORT
DESCRIPTOR.message_types_by_name['ApplicationMeteringReport'] = _APPLICATIONMETERINGREPORT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetMeteringReportRequest = _reflection.GeneratedProtocolMessageType('GetMeteringReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMETERINGREPORTREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.admin.metering_report_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.GetMeteringReportRequest)
  })
_sym_db.RegisterMessage(GetMeteringReportRequest)

GetMeteringReportResponse = _reflection.GeneratedProtocolMessageType('GetMeteringReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMETERINGREPORTRESPONSE,
  '__module__' : 'com.daml.ledger.api.v1.admin.metering_report_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.GetMeteringReportResponse)
  })
_sym_db.RegisterMessage(GetMeteringReportResponse)

ParticipantMeteringReport = _reflection.GeneratedProtocolMessageType('ParticipantMeteringReport', (_message.Message,), {
  'DESCRIPTOR' : _PARTICIPANTMETERINGREPORT,
  '__module__' : 'com.daml.ledger.api.v1.admin.metering_report_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.ParticipantMeteringReport)
  })
_sym_db.RegisterMessage(ParticipantMeteringReport)

ApplicationMeteringReport = _reflection.GeneratedProtocolMessageType('ApplicationMeteringReport', (_message.Message,), {
  'DESCRIPTOR' : _APPLICATIONMETERINGREPORT,
  '__module__' : 'com.daml.ledger.api.v1.admin.metering_report_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.admin.ApplicationMeteringReport)
  })
_sym_db.RegisterMessage(ApplicationMeteringReport)


DESCRIPTOR._options = None

_METERINGREPORTSERVICE = _descriptor.ServiceDescriptor(
  name='MeteringReportService',
  full_name='com.daml.ledger.api.v1.admin.MeteringReportService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=917,
  serialized_end=1075,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetMeteringReport',
    full_name='com.daml.ledger.api.v1.admin.MeteringReportService.GetMeteringReport',
    index=0,
    containing_service=None,
    input_type=_GETMETERINGREPORTREQUEST,
    output_type=_GETMETERINGREPORTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_METERINGREPORTSERVICE)

DESCRIPTOR.services_by_name['MeteringReportService'] = _METERINGREPORTSERVICE

# @@protoc_insertion_point(module_scope)
