# Copyright (c) 2017-2022 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/version_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import experimental_features_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v1_dot_experimental__features__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='com/daml/ledger/api/v1/version_service.proto',
  package='com.daml.ledger.api.v1',
  syntax='proto3',
  serialized_options=b'\n\026com.daml.ledger.api.v1B\030VersionServiceOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,com/daml/ledger/api/v1/version_service.proto\x12\x16\x63om.daml.ledger.api.v1\x1a\x32\x63om/daml/ledger/api/v1/experimental_features.proto\"9\n\x1aGetLedgerApiVersionRequest\x12\x1b\n\tledger_id\x18\x01 \x01(\tR\x08ledgerId\"\x7f\n\x1bGetLedgerApiVersionResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x46\n\x08\x66\x65\x61tures\x18\x02 \x01(\x0b\x32*.com.daml.ledger.api.v1.FeaturesDescriptorR\x08\x66\x65\x61tures\"\xa9\x02\n\x12\x46\x65\x61turesDescriptor\x12V\n\x0fuser_management\x18\x02 \x01(\x0b\x32-.com.daml.ledger.api.v1.UserManagementFeatureR\x0euserManagement\x12P\n\x0c\x65xperimental\x18\x01 \x01(\x0b\x32,.com.daml.ledger.api.v1.ExperimentalFeaturesR\x0c\x65xperimental\x12i\n\x15\x63ommand_deduplication\x18\x03 \x01(\x0b\x32\x34.com.daml.ledger.api.v1.CommandDeduplicationFeaturesR\x14\x63ommandDeduplication\"\x17\n\x15UserManagementFeature\"\x9a\x02\n\x1c\x43ommandDeduplicationFeatures\x12t\n\x1c\x64\x65\x64uplication_period_support\x18\x01 \x01(\x0b\x32\x32.com.daml.ledger.api.v1.DeduplicationPeriodSupportR\x1a\x64\x65\x64uplicationPeriodSupport\x12\x83\x01\n!participant_deduplication_support\x18\x02 \x01(\x0e\x32\x37.com.daml.ledger.api.v1.ParticipantDeduplicationSupportR\x1fparticipantDeduplicationSupport\"\xaa\x03\n\x1a\x44\x65\x64uplicationPeriodSupport\x12g\n\x0eoffset_support\x18\x01 \x01(\x0e\x32@.com.daml.ledger.api.v1.DeduplicationPeriodSupport.OffsetSupportR\roffsetSupport\x12m\n\x10\x64uration_support\x18\x02 \x01(\x0e\x32\x42.com.daml.ledger.api.v1.DeduplicationPeriodSupport.DurationSupportR\x0f\x64urationSupport\"d\n\rOffsetSupport\x12\x19\n\x15OFFSET_NATIVE_SUPPORT\x10\x00\x12\x1e\n\x1aOFFSET_CONVERT_TO_DURATION\x10\x01\x12\x18\n\x14OFFSET_NOT_SUPPORTED\x10\x02\"N\n\x0f\x44urationSupport\x12\x1b\n\x17\x44URATION_NATIVE_SUPPORT\x10\x00\x12\x1e\n\x1a\x44URATION_CONVERT_TO_OFFSET\x10\x01*\xa4\x01\n\x1fParticipantDeduplicationSupport\x12+\n\'PARTICIPANT_DEDUPLICATION_NOT_SUPPORTED\x10\x00\x12+\n\'PARTICIPANT_DEDUPLICATION_PARALLEL_ONLY\x10\x01\x12\'\n#PARTICIPANT_DEDUPLICATION_SUPPORTED\x10\x02\x32\x90\x01\n\x0eVersionService\x12~\n\x13GetLedgerApiVersion\x12\x32.com.daml.ledger.api.v1.GetLedgerApiVersionRequest\x1a\x33.com.daml.ledger.api.v1.GetLedgerApiVersionResponseB\x9c\x01\n\x16\x63om.daml.ledger.api.v1B\x18VersionServiceOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3'
  ,
  dependencies=[com_dot_daml_dot_ledger_dot_api_dot_v1_dot_experimental__features__pb2.DESCRIPTOR,])

_PARTICIPANTDEDUPLICATIONSUPPORT = _descriptor.EnumDescriptor(
  name='ParticipantDeduplicationSupport',
  full_name='com.daml.ledger.api.v1.ParticipantDeduplicationSupport',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARTICIPANT_DEDUPLICATION_NOT_SUPPORTED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARTICIPANT_DEDUPLICATION_PARALLEL_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARTICIPANT_DEDUPLICATION_SUPPORTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1352,
  serialized_end=1516,
)
_sym_db.RegisterEnumDescriptor(_PARTICIPANTDEDUPLICATIONSUPPORT)

ParticipantDeduplicationSupport = enum_type_wrapper.EnumTypeWrapper(_PARTICIPANTDEDUPLICATIONSUPPORT)
PARTICIPANT_DEDUPLICATION_NOT_SUPPORTED = 0
PARTICIPANT_DEDUPLICATION_PARALLEL_ONLY = 1
PARTICIPANT_DEDUPLICATION_SUPPORTED = 2


_DEDUPLICATIONPERIODSUPPORT_OFFSETSUPPORT = _descriptor.EnumDescriptor(
  name='OffsetSupport',
  full_name='com.daml.ledger.api.v1.DeduplicationPeriodSupport.OffsetSupport',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OFFSET_NATIVE_SUPPORT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OFFSET_CONVERT_TO_DURATION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OFFSET_NOT_SUPPORTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1169,
  serialized_end=1269,
)
_sym_db.RegisterEnumDescriptor(_DEDUPLICATIONPERIODSUPPORT_OFFSETSUPPORT)

_DEDUPLICATIONPERIODSUPPORT_DURATIONSUPPORT = _descriptor.EnumDescriptor(
  name='DurationSupport',
  full_name='com.daml.ledger.api.v1.DeduplicationPeriodSupport.DurationSupport',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DURATION_NATIVE_SUPPORT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DURATION_CONVERT_TO_OFFSET', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1271,
  serialized_end=1349,
)
_sym_db.RegisterEnumDescriptor(_DEDUPLICATIONPERIODSUPPORT_DURATIONSUPPORT)


_GETLEDGERAPIVERSIONREQUEST = _descriptor.Descriptor(
  name='GetLedgerApiVersionRequest',
  full_name='com.daml.ledger.api.v1.GetLedgerApiVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_id', full_name='com.daml.ledger.api.v1.GetLedgerApiVersionRequest.ledger_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ledgerId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=181,
)


_GETLEDGERAPIVERSIONRESPONSE = _descriptor.Descriptor(
  name='GetLedgerApiVersionResponse',
  full_name='com.daml.ledger.api.v1.GetLedgerApiVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='com.daml.ledger.api.v1.GetLedgerApiVersionResponse.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='version', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='com.daml.ledger.api.v1.GetLedgerApiVersionResponse.features', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='features', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=310,
)


_FEATURESDESCRIPTOR = _descriptor.Descriptor(
  name='FeaturesDescriptor',
  full_name='com.daml.ledger.api.v1.FeaturesDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_management', full_name='com.daml.ledger.api.v1.FeaturesDescriptor.user_management', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userManagement', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='experimental', full_name='com.daml.ledger.api.v1.FeaturesDescriptor.experimental', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='experimental', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_deduplication', full_name='com.daml.ledger.api.v1.FeaturesDescriptor.command_deduplication', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commandDeduplication', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=610,
)


_USERMANAGEMENTFEATURE = _descriptor.Descriptor(
  name='UserManagementFeature',
  full_name='com.daml.ledger.api.v1.UserManagementFeature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=612,
  serialized_end=635,
)


_COMMANDDEDUPLICATIONFEATURES = _descriptor.Descriptor(
  name='CommandDeduplicationFeatures',
  full_name='com.daml.ledger.api.v1.CommandDeduplicationFeatures',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deduplication_period_support', full_name='com.daml.ledger.api.v1.CommandDeduplicationFeatures.deduplication_period_support', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deduplicationPeriodSupport', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_deduplication_support', full_name='com.daml.ledger.api.v1.CommandDeduplicationFeatures.participant_deduplication_support', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='participantDeduplicationSupport', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=638,
  serialized_end=920,
)


_DEDUPLICATIONPERIODSUPPORT = _descriptor.Descriptor(
  name='DeduplicationPeriodSupport',
  full_name='com.daml.ledger.api.v1.DeduplicationPeriodSupport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset_support', full_name='com.daml.ledger.api.v1.DeduplicationPeriodSupport.offset_support', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offsetSupport', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration_support', full_name='com.daml.ledger.api.v1.DeduplicationPeriodSupport.duration_support', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='durationSupport', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEDUPLICATIONPERIODSUPPORT_OFFSETSUPPORT,
    _DEDUPLICATIONPERIODSUPPORT_DURATIONSUPPORT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=923,
  serialized_end=1349,
)

_GETLEDGERAPIVERSIONRESPONSE.fields_by_name['features'].message_type = _FEATURESDESCRIPTOR
_FEATURESDESCRIPTOR.fields_by_name['user_management'].message_type = _USERMANAGEMENTFEATURE
_FEATURESDESCRIPTOR.fields_by_name['experimental'].message_type = com_dot_daml_dot_ledger_dot_api_dot_v1_dot_experimental__features__pb2._EXPERIMENTALFEATURES
_FEATURESDESCRIPTOR.fields_by_name['command_deduplication'].message_type = _COMMANDDEDUPLICATIONFEATURES
_COMMANDDEDUPLICATIONFEATURES.fields_by_name['deduplication_period_support'].message_type = _DEDUPLICATIONPERIODSUPPORT
_COMMANDDEDUPLICATIONFEATURES.fields_by_name['participant_deduplication_support'].enum_type = _PARTICIPANTDEDUPLICATIONSUPPORT
_DEDUPLICATIONPERIODSUPPORT.fields_by_name['offset_support'].enum_type = _DEDUPLICATIONPERIODSUPPORT_OFFSETSUPPORT
_DEDUPLICATIONPERIODSUPPORT.fields_by_name['duration_support'].enum_type = _DEDUPLICATIONPERIODSUPPORT_DURATIONSUPPORT
_DEDUPLICATIONPERIODSUPPORT_OFFSETSUPPORT.containing_type = _DEDUPLICATIONPERIODSUPPORT
_DEDUPLICATIONPERIODSUPPORT_DURATIONSUPPORT.containing_type = _DEDUPLICATIONPERIODSUPPORT
DESCRIPTOR.message_types_by_name['GetLedgerApiVersionRequest'] = _GETLEDGERAPIVERSIONREQUEST
DESCRIPTOR.message_types_by_name['GetLedgerApiVersionResponse'] = _GETLEDGERAPIVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['FeaturesDescriptor'] = _FEATURESDESCRIPTOR
DESCRIPTOR.message_types_by_name['UserManagementFeature'] = _USERMANAGEMENTFEATURE
DESCRIPTOR.message_types_by_name['CommandDeduplicationFeatures'] = _COMMANDDEDUPLICATIONFEATURES
DESCRIPTOR.message_types_by_name['DeduplicationPeriodSupport'] = _DEDUPLICATIONPERIODSUPPORT
DESCRIPTOR.enum_types_by_name['ParticipantDeduplicationSupport'] = _PARTICIPANTDEDUPLICATIONSUPPORT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLedgerApiVersionRequest = _reflection.GeneratedProtocolMessageType('GetLedgerApiVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERAPIVERSIONREQUEST,
  '__module__' : 'com.daml.ledger.api.v1.version_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetLedgerApiVersionRequest)
  })
_sym_db.RegisterMessage(GetLedgerApiVersionRequest)

GetLedgerApiVersionResponse = _reflection.GeneratedProtocolMessageType('GetLedgerApiVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLEDGERAPIVERSIONRESPONSE,
  '__module__' : 'com.daml.ledger.api.v1.version_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetLedgerApiVersionResponse)
  })
_sym_db.RegisterMessage(GetLedgerApiVersionResponse)

FeaturesDescriptor = _reflection.GeneratedProtocolMessageType('FeaturesDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESDESCRIPTOR,
  '__module__' : 'com.daml.ledger.api.v1.version_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.FeaturesDescriptor)
  })
_sym_db.RegisterMessage(FeaturesDescriptor)

UserManagementFeature = _reflection.GeneratedProtocolMessageType('UserManagementFeature', (_message.Message,), {
  'DESCRIPTOR' : _USERMANAGEMENTFEATURE,
  '__module__' : 'com.daml.ledger.api.v1.version_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.UserManagementFeature)
  })
_sym_db.RegisterMessage(UserManagementFeature)

CommandDeduplicationFeatures = _reflection.GeneratedProtocolMessageType('CommandDeduplicationFeatures', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDDEDUPLICATIONFEATURES,
  '__module__' : 'com.daml.ledger.api.v1.version_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.CommandDeduplicationFeatures)
  })
_sym_db.RegisterMessage(CommandDeduplicationFeatures)

DeduplicationPeriodSupport = _reflection.GeneratedProtocolMessageType('DeduplicationPeriodSupport', (_message.Message,), {
  'DESCRIPTOR' : _DEDUPLICATIONPERIODSUPPORT,
  '__module__' : 'com.daml.ledger.api.v1.version_service_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.DeduplicationPeriodSupport)
  })
_sym_db.RegisterMessage(DeduplicationPeriodSupport)


DESCRIPTOR._options = None

_VERSIONSERVICE = _descriptor.ServiceDescriptor(
  name='VersionService',
  full_name='com.daml.ledger.api.v1.VersionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1519,
  serialized_end=1663,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetLedgerApiVersion',
    full_name='com.daml.ledger.api.v1.VersionService.GetLedgerApiVersion',
    index=0,
    containing_service=None,
    input_type=_GETLEDGERAPIVERSIONREQUEST,
    output_type=_GETLEDGERAPIVERSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VERSIONSERVICE)

DESCRIPTOR.services_by_name['VersionService'] = _VERSIONSERVICE

# @@protoc_insertion_point(module_scope)
