# Copyright (c) 2017-2022 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/experimental_features.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='com/daml/ledger/api/v1/experimental_features.proto',
  package='com.daml.ledger.api.v1',
  syntax='proto3',
  serialized_options=b'\n\026com.daml.ledger.api.v1B\036ExperimentalFeaturesOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2com/daml/ledger/api/v1/experimental_features.proto\x12\x16\x63om.daml.ledger.api.v1\"\x8a\x01\n\x14\x45xperimentalFeatures\x12r\n\x18self_service_error_codes\x18\x01 \x01(\x0b\x32\x39.com.daml.ledger.api.v1.ExperimentalSelfServiceErrorCodesR\x15selfServiceErrorCodes\"#\n!ExperimentalSelfServiceErrorCodesB\xa2\x01\n\x16\x63om.daml.ledger.api.v1B\x1e\x45xperimentalFeaturesOuterClassZOgithub.com/digital-asset/dazl-client/go/v7/pkg/generated/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3'
)




_EXPERIMENTALFEATURES = _descriptor.Descriptor(
  name='ExperimentalFeatures',
  full_name='com.daml.ledger.api.v1.ExperimentalFeatures',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='self_service_error_codes', full_name='com.daml.ledger.api.v1.ExperimentalFeatures.self_service_error_codes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='selfServiceErrorCodes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=217,
)


_EXPERIMENTALSELFSERVICEERRORCODES = _descriptor.Descriptor(
  name='ExperimentalSelfServiceErrorCodes',
  full_name='com.daml.ledger.api.v1.ExperimentalSelfServiceErrorCodes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=219,
  serialized_end=254,
)

_EXPERIMENTALFEATURES.fields_by_name['self_service_error_codes'].message_type = _EXPERIMENTALSELFSERVICEERRORCODES
DESCRIPTOR.message_types_by_name['ExperimentalFeatures'] = _EXPERIMENTALFEATURES
DESCRIPTOR.message_types_by_name['ExperimentalSelfServiceErrorCodes'] = _EXPERIMENTALSELFSERVICEERRORCODES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExperimentalFeatures = _reflection.GeneratedProtocolMessageType('ExperimentalFeatures', (_message.Message,), {
  'DESCRIPTOR' : _EXPERIMENTALFEATURES,
  '__module__' : 'com.daml.ledger.api.v1.experimental_features_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.ExperimentalFeatures)
  })
_sym_db.RegisterMessage(ExperimentalFeatures)

ExperimentalSelfServiceErrorCodes = _reflection.GeneratedProtocolMessageType('ExperimentalSelfServiceErrorCodes', (_message.Message,), {
  'DESCRIPTOR' : _EXPERIMENTALSELFSERVICEERRORCODES,
  '__module__' : 'com.daml.ledger.api.v1.experimental_features_pb2'
  # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.ExperimentalSelfServiceErrorCodes)
  })
_sym_db.RegisterMessage(ExperimentalSelfServiceErrorCodes)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
